<?php


class TurnstileSettingsPage {
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct(){
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    /**
     * Add options page
     */
    public function add_plugin_page(){
        // This page will be under "Settings"
        add_options_page(
            'Turnstile',
            'Turnstile user tracking',
            'manage_options',
            'turnstile-setting-admin',
            array( $this, 'render_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function render_admin_page(){
        // Set class property
        $this->options = get_option( 'turnstile_api' );
        if ( empty($this->options) || TURNSTILE_DEBUG_INSTALLATION_SCREEN ){
            $this->render_admin_page_not_register();
        } else {
            $this->render_admin_page_already_register();
        }
    }
    public function render_admin_page_already_register(){
        ?>
            <div class="turnstile-settings-admin nowrap ts-center ts-gradient1 ts-H120">
                    <a href="https://turnstile.me/my_turnstiles" class="ts-clean-link">
                        <h1 class="ts-txt-white ts-margin0 ts-paddingV50 ts-txt-bigtitle">All done!</h1>
                    </a>
            </div>
            <div class="turnstile-settings-admin nowrap ts-center ts-paddingV50">
                <h2>Turnstile was <span class="ts-gradient1 ts-padding5">successfully</span> installed</h2>
            </div>
            <div class="turnstile-settings-admin nowrap ts-center ts-paddingV50">
                <div class="ts-maxwidth480 ts-margin0 ts-alignleft">
                    <p class="ts-center ts-txt-bigsubtitle">Now what?</p>
                    <h3><span class="ts-gradient1 ts-padding5 ts-bold">1</span>  Discover your audience</h3>
                    <ol>
                        <li>Click the "new Turnstile" button in your visual editor
                        <img height="24" width="24" class="ts-icon_turnstile" src="<?php echo turnstile_img_path("turnstile_logo_64.png"); ?>"></li>
                        <li>
                            Put the content you want to track behind the shortcode
                        </li>
                        <li>
                            Select your preferred social-login providers from the Turnstile option box before publishing
                        </li>
                    </ol>

                    <h3><span class="ts-gradient1 ts-padding5 ts-bold">2</span>  Reach out to your audience</h3>
                    <ol>
                        <li>Contact information for each visitor will appear in your editor window</li>
                        <li>See all your metrics at <a href="https://turnstile.me/my_turnstiles">turnstile.me</a> </li>
                    </ol>
                    <h3><span class="ts-gradient1 ts-padding5 ts-bold">3</span>  Be creative!</h3>
                    <ol>
                        <li>Visite <a href="https://turnstile.me/">turnstile.me</a> to create smartlinks that track your followers on social media</li>
                        <li>Monitor bonus content and identify your most loyal fans</li>
                        <li>Organize a contest and pick influential winners</li>
                        <li>Visit us on Twitter <a href="https://twitter.com/TurnstileMe">@TurnstileMe</a> for more tips and updates</li>
                    </ol>

                </div>
            </div>
        <?php
    }
    public function render_admin_page_not_register(){
        ?>

            <div class="turnstile-settings-admin nowrap ts-center ts-gradient1 ts-H120">
                    <h1 class="ts-txt-white ts-margin0 ts-paddingV50 ts-txt-bigtitle">Great!</h1>
            </div>

            <div class="turnstile-settings-admin nowrap ts-center ts-paddingV50">
                <div class="ts-maxwidth480 ts-margin0 ts-alignleft">
                    <p class="ts-center">You successfully installed the Turnstile plugin.</p>
                    <p class="ts-center"> <strong> One last thing</strong>:  you need to connect to your Turnstile account.</p>
                </div>
            </div>

            <div class="turnstile-settings-admin wrap">

                <form method="post" action="admin-ajax.php?action=connect_with_turnstile">

                <?php
                    // This prints out all hidden setting fields
                    //settings_fields( 'turnstile_option_group' );
                    // do_settings_sections( 'turnstile-setting-admin' );
                    submit_button(__('Connect with Turnstile'), "button-primary draw meet");

                ?>
                </form>
            </div>
        <?php
    }


    /**
     * Register and add settings
     */
    public function page_init(){
        register_setting(
            'turnstile_option_group', // Option group
            'turnstile_api', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'setting_section_id', // ID
            'API Settings', // Title
            array( $this, 'print_section_info' ), // Callback
            'turnstile-setting-admin' // Page
        );

        add_settings_section(
            'plugin_settings',
            'Plugin Settings',
            array( $this, 'render_setting_section_description' ),
            'general'
            //'turnstile-setting-admin'
        );

        add_settings_field(
            'turnstile_cookie_bar_enabled',
            'GDPR Compliance',
            array( $this, 'render_cookie_bar_input' ),
            'general',
            'plugin_settings'
        );

        register_setting( 'general', 'turnstile_cookie_bar_enabled' );
    }

    public function render_setting_section_description() {
        echo '<p>Turnstile Plugin Settings</p>';
    }

    public function render_cookie_bar_input() {
        echo '<input name="turnstile_cookie_bar_enabled" id="turnstile_cookie_bar_enabled" type="checkbox" value="1" class="code" ' . checked( 1, get_option( 'turnstile_cookie_bar_enabled' ), false ) . ' /> Enable Turnstile user data policy overlay';
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input ){
        $new_input = array();

        if( isset( $input['client_id'] ) )
            $new_input['client_id'] = sanitize_text_field( $input['client_id'] );
        if( isset( $input['client_secret'] ) )
            $new_input['client_secret'] = sanitize_text_field( $input['client_secret'] );
        if( isset( $input['timestamp'] ) )
            $new_input['timestamp'] = $input['timestamp'];
        return $new_input;
    }

    /**
     * Print the Section text
     */


    public function print_section_info(){
        // Notices
        $url = add_query_arg( array( 'authorized' => False ) );
        if ( isset( $_GET['authorized'] ) && $_GET['authorized'] == 'success' ){
            $class = 'notice notice-success';
            $message = __( 'Success authorizing Turnstile application', 'turnstile' );
            printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) );
        } elseif ( isset( $_GET['authorized'] ) && $_GET['authorized'] == 'error' ){
            $class = 'notice notice-error';
            $message = __( 'An error occurred while authorizing the Turnstile application.', 'turnstile' );
            printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) );
        }

print <<<EOT
<p>
  Connect your Turnstile account to begin using the plugin.
</p>
EOT;

    }

    /**
     * Get the settings option array and print one of its values
     */

    public function client_id_callback(){
        printf(
            '<input type="text" id="client_id" name="turnstile_api[client_id]" value="%s" />',
            isset( $this->options['client_id'] ) ? esc_attr( $this->options['client_id']) : ''
        );
    }
    public function client_secret_callback(){
        printf(
            '<input type="text" id="client_secret" name="turnstile_api[client_secret]" value="%s" />',
            isset( $this->options['client_secret'] ) ? esc_attr( $this->options['client_secret']) : ''
        );
    }
}

if( is_admin() ){
    $my_settings_page = new TurnstileSettingsPage();
}



function menu_html(){
    echo '<h1>'.get_admin_page_title().'</h1>';
    ?>
    <form method="post" action="options.php">
      <?php settings_fields('turnstile_option_group') ?>

      <input type="text" name="turnstile_api" value="<?php echo get_option('turnstile_api')?>"/>
      <?php submit_button(); ?>
    </form>
  <?php
}
