<?php
defined( 'ABSPATH' ) or die( 'Unauthorized' );

function turnstile_social_array(){
    $social_available = array(
        'facebook'  => 'fb',
        'linkedin'  => 'lk',
        'twitter'   => 'tw',
        'google'    => 'google',
        'pinterest' => 'pin',
        'instagram' => 'insta',
        'snapchat'  => 'snap');

    $social = array();
    foreach ($social_available as $key => $value) {
        $social['ask_' . $value] = False;
        if ( turnstile_ask_get_meta( $key ) == 1 ) {
            $social['ask_' . $value] = True;
        }
    }
    return $social;
}

function apifylink( $turnstile_link ) {
    if ( isset( $turnstile_link ) && $turnstile_link != "" ) {
        $turnstile_link = str_replace( turnstile_url(''), turnstile_api_url('api/turnstiles/'), $turnstile_link[0]);
        return $turnstile_link . "/";
    } else {
        return False;
    }

}

function turnstile_refresh_token(){
    $url_ajax = admin_url('admin-ajax.php');
    $url_turnstile = turnstile_api_url('o/token/');


    $client_id = get_option( 'turnstile_api' )['client_id'];
    $client_secret = get_option( 'turnstile_api' )['client_secret'];
    $refresh_token = get_option( 'turnstile_refresh_token' );

    $params = array( 'client_id'     => $client_id,
                     'client_secret' => $client_secret,
                     'grant_type'    => 'refresh_token',
                     'refresh_token'  => $refresh_token );

    $args = array( 'method' => 'POST',
                   'timeout' => 10,
                   'redirection' => 2,
                   'headers' => array(),
                   'body' => $params );
    $response = wp_remote_post( $url_turnstile, $args );


    if ( is_array( $response ) ) {
        $header = $response['headers']; // array of http header lines
        $body = json_decode( $response['body'], True ); // use the content
      }

    header( "Content-Type: application/json" );
    if (isset($body['access_token'])){
        update_option( 'turnstile_access_token', $body['access_token'] );
        update_option( 'turnstile_refresh_token', $body['refresh_token'] );
        update_option( 'turnstile_token_type', $body['token_type'] );
        update_option( 'turnstile_scope', $body['scope'] );
        return $body['access_token'];
    }
    return False;

}

// Add a turnstile link to the post custom field when it's published or saved
// this adds the turnstile-readmore-self field to the article, enabling
// the shortcode [turnstile_more] content to hide [/turnstile_more]
// without the need of any arg like [turnstile_more link="http://external-link.com"]
// external links can be used to send user at the original source article
function publish_event_add_turnstile_link_more( $ID ) {
    $permalink = get_permalink( $ID );
    $url_website = get_site_url();

    $data = turnstile_social_array();
    $turnstile_link = get_post_meta( $ID, 'turnstile-readmore-self' );

    if ( false == $turnstile_link || 0 == strlen( $turnstile_link[0] ) ) {
        $method = "POST";  // create new link
        $data = array_merge( $data, array(
            "url"   =>  $permalink,
            "embedded" => true
        ));
        $url_api = turnstile_api_url('api/turnstiles/');
    } else {
        $method = "PATCH";  // update link
        $url_api = apifylink($turnstile_link);
        $data = array_merge( $data, array(
            "url"   =>  $permalink
        ));
    }

    turnstile_refresh_token();  // refresh access token each time

    $args = array(
        'method' => $method,
        'timeout' => 10,
        'redirection' => 2,
        'headers' => array(
            "ORIGIN"        =>  $url_website,
            "Content-type"  =>  "application/x-www-form-urlencoded",
            "Authorization" =>  "Bearer " . get_option( "turnstile_access_token", "" )
        ),
        'body' => $data
    );

    $response = wp_remote_post( $url_api, $args );

    if ( is_array( $response ) ) {
        $header = $response['headers']; // array of http header lines
        $body = json_decode( $response['body'], True );
    }

    if ( isset( $body['link'] ) ) {
        $turnstile_link = turnstile_url($body['link']);
        update_post_meta( $ID, 'turnstile-readmore-self', $turnstile_link );
    } elseif ( isset( $body['name'] ) ) {
        $turnstile_link = str_replace( "b'", "", $body['name']);
        $turnstile_link = str_replace( "'", "", $turnstile_link);
        $turnstile_link = turnstile_url( $turnstile_link );
        update_post_meta( $ID, 'turnstile-readmore-self', $turnstile_link );
    } else {
        // error
    }


}
// add_action( 'publish_post', 'publish_event_add_turnstile_link_more', 10, 2 );
